/*++

Copyright (c) Pico Systems Co., Ltd.

Module Name:

    bvcm.h

Abstract:

    Bill Validater , Coin Mechanism device driver
    BVCM Dynamic Link library definitions

Revision History:

    20/Sep/2005   Created by Makoto Ito
	
--*/

#include "windows.h"

#ifndef BVCM_H
#define BVCM_H


// The following ifdef block is the standard way of creating macros
// which make exporting from a DLL simpler.

#ifdef BVCM_EXPORTS
#define BVCM_API __declspec(dllexport)
#else
#define BVCM_API __declspec(dllimport)
#endif


// Type Definition

typedef PVOID	BVCM_HANDLE;
typedef ULONG	BVCM_STATUS;


// Device status

enum
{
    BVCM_OK,
    BVCM_INVALID_HANDLE,
    BVCM_IO_ERROR,
    BVCM_INVALID_PARAMETER,
    BVCM_NO_RESPONSE,
	BVCM_OTHER_ERROR,
	BVCM_ACK1,
	BVCM_ACK2,
	BVCM_ACK3,
	BVCM_ACK4,
	BVCM_NAK,
	BVCM_BUSY
};

// Device Type

enum
{
	BVCM_BILL,
	BVCM_COIN
};

// Function for Export

BVCM_API
BVCM_STATUS WINAPI BVCM_ScanInterface
(
	unsigned int* puiNumber
);

BVCM_API
BVCM_STATUS WINAPI BVCM_OpenInterface
(
	unsigned int uiInterface,
	BVCM_HANDLE *bvcmHandle
);

BVCM_API
BVCM_STATUS WINAPI BVCM_CloseInterface
(
	BVCM_HANDLE bvcmHandle
);

BVCM_API
BVCM_STATUS WINAPI BVCM_Standby
(
	BVCM_HANDLE bvcmHandle,
	unsigned int uiTarget
);

BVCM_API
BVCM_STATUS WINAPI BVCM_GetAllData
(
	BVCM_HANDLE bvcmHandle,
	unsigned int uiTarget,
	PCHAR pcBuffer,
	unsigned int uiBufferSize
);

BVCM_API
BVCM_STATUS WINAPI BVCM_GetData
(
	BVCM_HANDLE bvcmHandle,
	unsigned int uiTarget,
	PCHAR pcBuffer,
	unsigned int uiBufferSize
);

BVCM_API
BVCM_STATUS WINAPI BVCM_PutData
(
	BVCM_HANDLE bvcmHandle,
	unsigned int uiTarget,
	PCHAR pcBuffer
);

BVCM_API
BVCM_STATUS WINAPI BVCM_LineReset
(
	BVCM_HANDLE bvcmHandle
);

#endif
